<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Traducteurs</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Navigateur YouTube%1 pour SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Version : %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Edition portable</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Compilé avec Qt %1 (en utilisant %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Visitez notre site web pour les mises à jour :</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>De nombreuses personnes ont participées aux traductions.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Vous aussi, vous pouvez nous aider pour traduire SMTube dans votre langue.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Visitez %1 et rejoignez une équipe de traduction.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Cliquez içi pour connaitre les traducteurs des équipes transifex.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="125"/>
        <source>Home</source>
        <translation>Maison</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="128"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="136"/>
        <source>Zoom +</source>
        <translation>Zoom +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="140"/>
        <source>Zoom -</source>
        <translation>Zoom -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="144"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Navigation</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="159"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>Toolbar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="164"/>
        <source>Statusbar</source>
        <translation>Barre de statut</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="168"/>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="179"/>
        <source>&amp;Update the YouTube code</source>
        <translation>&amp;Mise à jour du code YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="185"/>
        <source>About this &amp;release</source>
        <translation>À propos de cette &amp;version</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="190"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;À propos de SMTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="298"/>
        <source>Download video using an external service</source>
        <translation>Télécharger la vidéo à l&apos;aide d&apos;un service externe</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="299"/>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="527"/>
        <source>Connection failed</source>
        <translation>Connexion échouée</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="528"/>
        <source>The video you requested needs to open a HTTPS connection.</source>
        <translation>La vidéo demandée nécessite d&apos;ouvrir une connexion HTTPS.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="529"/>
        <source>Unfortunately the OpenSSL component, required for it, is not available in your system.</source>
        <translation>Malheureusement, le composant OpenSSL requis n&apos;est pas disponible sur votre système.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="534"/>
        <source>No video found</source>
        <translation>Aucune vidéo trouvée</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="535"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Impossible de trouver l&apos;URL pour cette vidéo.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="545"/>
        <location filename="../browserwindow.cpp" line="553"/>
        <source>Problems with YouTube</source>
        <translation>Problèmes avec YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="546"/>
        <location filename="../browserwindow.cpp" line="554"/>
        <source>Unfortunately due to changes in YouTube, the video &apos;%1&apos; can&apos;t be played.</source>
        <translation>Malheureusement, à cause de changements dans Youtube, il est impossible de lire la vidéo &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="547"/>
        <source>Do you want to update the YouTube code? This may fix the problem.</source>
        <translation>Voulez-vous mettre à jour le code Youtube ? Cela pourrait résoudre le problème.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="555"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Une mise à jour de l&apos;application pourrait résoudre ce problème.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="574"/>
        <source>About this release</source>
        <translation>À propos de cette version</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="575"/>
        <source>Due to changes in YouTube, the old SMTube doesn&apos;t work anymore.</source>
        <translation>A cause de changements dans YouTube, l&apos;ancien SMTube ne fonctionne plus.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="576"/>
        <source>This is a new version of SMTube, written from scratch.</source>
        <translation>Ceci est une nouvelle version de SMTube, réécrite totalement.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="577"/>
        <source>Some functionality is not available yet.</source>
        <translation>Quelques fonctionnalités ne sont toujours pas disponibles.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>Important:</source>
        <translation>Important :</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="580"/>
        <source>If the VEVO videos fail to play, please use the option %1 in the Help menu.</source>
        <translation>Si les vidéos VEVO refusent de fonctionner, utilisez l&apos;option %1 dans le menu d&apos;Aide.</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="581"/>
        <source>Update the YouTube code</source>
        <translation>Mettre à jour le code YouTube</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="284"/>
        <source>Loading... %1%</source>
        <translation>Chargement... %1%</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Général</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="108"/>
        <source>&amp;Players</source>
        <translation>&amp;Lecteurs</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="156"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="121"/>
        <source>Up</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>&amp;Qualité préférée :</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="167"/>
        <source>Delete</source>
        <translation>Suppression</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Edit</source>
        <translation>Edition</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="204"/>
        <source>A&amp;dd predefined players</source>
        <translation>A&amp;jout de lecteurs prédéfinis</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="240"/>
        <source>&amp;Interface</source>
        <translation>&amp;Interface</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="248"/>
        <source>&amp;Style:</source>
        <translation>&amp;Style :</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="284"/>
        <source>Font:</source>
        <translation>Police :</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>C&amp;hange...</source>
        <translation>C&amp;hanger...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Télécharger la vidéo à l&apos;aide d&apos;un service &amp;externe</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="132"/>
        <source>Down</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Cliquez pour sélectionner un fichier ou un répertoire</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Ouvrir le lien dans cette fenêtre</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Editer Lecteur</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nom :</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Exécutable :</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Paramètres :</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Ce lecteur supporte les sites de &amp;vidéo</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Ce lecteur supporte les TV &amp;en ligne</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>&amp;Qualité préférée :</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>Ajouter dans le &amp;menu :</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Vidéo et audio</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
</context>
</TS>
